# Documentation

This folder contains a series of subfolders ([`general`](/docs/general/introduction.md) and [`tutorial`](/docs/tutorial/01-overview.md)) with documentation in [Markdown](https://en.wikipedia.org/wiki/Markdown).

Additionally, it contains the [sources](/docs/website/) of SLJIT's [website](https://zherczeg.github.io/sljit/).

> [!NOTE]
> The documentation aims to display nicely when viewed on GitHub, as well as when processed by Docusaurus for the website.
